#!/bin/bash

version_of=OpenFOAM-2.3.x
version_tp=ThirdParty-2.3.x
compile_hosts="localhost" # l21:8
umask 0022
if [ $# -lt 1 ]; then
	echo "Usage: $0 <openfoam_install_dir>"
	echo ""
	echo "script will install:"
	echo "          $version_of to <openfoam_install_dir>/$version_of"
	echo "          $version_tp to <openfoam_install_dir>/$version_tp"
	echo ""
	echo "script must be executed from the directory where the source .tgz files are located!!!!"
  exit 1
fi

my_inst_dir=$1
mkdir -p $my_inst_dir
if [ -f ${version_of}.tgz ]; then
	tar zxvf ${version_of}.tgz -C ${my_inst_dir}
else
	echo "${version_of}.tgz not there; exiting"
	exit 1
fi
if [ -f ${version_of}.tgz ]; then
	tar zxvf ${version_tp}.tgz -C ${my_inst_dir}
else
        echo "${version_tp}.tgz not there; exiting"
        exit 1
fi


cd ${my_inst_dir}
mkdir not_used
mv ${version_tp}/openmpi-* not_used
mv ${version_tp}/ParaView-* not_used
#rm -rf not_used

cd ${my_inst_dir}
cp -n ${version_of}/etc/bashrc ${version_of}/etc/bashrc.orig
cat ${version_of}/etc/bashrc.orig | \
sed -e s/WM_MPLIB=OPENMPI/WM_MPLIB=INTELMPI/  | \
sed -e s/WM_COMPILER=Gcc/WM_COMPILER=Icc/ |\
sed -e s?foamInstall=\$HOME/\$WM_PROJECT?foamInstall=${my_inst_dir}? \
>  ${version_of}/etc/bashrc


echo 'INTELMPI)
        export MPI_ROOT=$I_MPI_ROOT
        export FOAM_MPI=intel_mpi.4.1.0.024
        export MPI_ARCH_PATH=$MPI_ROOT
        _foamAddPath    $MPI_ARCH_PATH/bin64
        _foamAddLib     $MPI_ARCH_PATH/lib64
        ;;' > mpi_settings.txt


cd ${my_inst_dir}
cp -n ${version_of}/etc/config/settings.sh ${version_of}/etc/config/settings.sh.orig
cat ${version_of}/etc/config/settings.sh.orig | \
sed -e '/SYSTEMOPENMPI)/r mpi_settings.txt' -e 'x;$G'  \
> ${version_of}/etc/config/settings.sh

cp -n ${version_of}/wmake/rules/linux64Icc/mplibINTELMPI  ${version_of}/wmake/rules/linux64Icc/mplibINTELMPI.orig
echo 'PFLAGS     = -DMPICH_SKIP_MPICXX
PINC       = -I$(MPI_ARCH_PATH)/include64
PLIBS      = -L$(MPI_ARCH_PATH)/lib64 -lmpi' > ${version_of}/wmake/rules/linux64Icc/mplibINTELMPI

#version 2.1.1 has fixed this bug!
#patch_file="src/finiteVolume/fields/fvPatchFields/constraint/wedge/wedgeFvPatchScalarField.C"
#cp -n ${version_of}/${patch_file} ${version_of}/${patch_file}.orig
#cat ${version_of}/${patch_file}.orig | \
#sed -e s/operator\=\=/this\-\>operator\=\=/ \
#> ${version_of}/${patch_file}

# version 2.2.0 does not have any EIO entries
#patch_file2="applications/solvers/stressAnalysis/solidDisplacementFoam/readMechanicalProperties.H"
#cp -n ${version_of}/${patch_file2} ${version_of}/${patch_file2}.orig
#cat ${version_of}/${patch_file2}.orig | \
#sed -e s/EIO/myEIO/ \
#> ${version_of}/${patch_file2}

rule_file="wmake/rules/linux64Icc/c++Opt"
cp -n ${version_of}/${rule_file} ${version_of}/${rule_file}.orig
echo 'c++DBUG     =
c++OPT      = -xSSE2 -O2 -no-prec-div' > ${version_of}/${rule_file}



cd ${my_inst_dir}
source ${version_of}/etc/bashrc
cd ${version_of}

export WM_SCHEDULER=wmakeScheduler
export WM_HOSTS="$compile_hosts"
export WM_NCOMPPROCS=$($WM_SCHEDULER -count)
export WM_COLOURS="black blue green cyan red magenta yellow" 

echo executing allwmake, check output in ${my_inst_dir}/${version_of}/allwmake.out
./Allwmake &> allwmake.out 

#decomposePar gives segmentation fault if this is not done:
#chmod 644 /opt/sw/OpenFOAM/OpenFOAM-2.2.2/OpenFOAM-2.2.2/etc/controlDict/controlDict

echo "add the following line to your .bashrc file"
echo "source ${my_inst_dir}/${version_of}/etc/bashrc"

